# Generated by Django 3.1.1 on 2020-09-04 02:30

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('wagtailcore', '0052_pagelogentry'),
    ]

    operations = [
        migrations.CreateModel(
            name='SeoSettings',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('og_meta', models.BooleanField(default=True, help_text='Show an optimized preview when linking to this site on social media. See https://ogp.me/', verbose_name='Use Open Graph Markup')),
                ('twitter_meta', models.BooleanField(default=True, help_text='Shows content as a card when linking to this site on Twitter. See https://developer.twitter.com/en/docs/twitter-for-websites/cards', verbose_name='Use Twitter Markup')),
                ('twitter_site', models.CharField(blank=True, help_text='The @username of the website owner’s Twitter handle.', max_length=16, verbose_name='Twitter Account')),
                ('struct_meta', models.BooleanField(default=True, help_text='Optimizes information about your organization for search engines. See https://schema.org/', verbose_name='Use Structured Data')),
                ('amp_pages', models.BooleanField(default=True, help_text='Generates an alternate AMP version of article pages that are preferred by search engines. See https://amp.dev/', verbose_name='Use AMP Pages')),
                ('site', models.OneToOneField(editable=False, on_delete=django.db.models.deletion.CASCADE, to='wagtailcore.site')),
            ],
            options={
                'verbose_name': 'SEO',
            },
        ),
    ]
