# Generated by Django 3.2.5 on 2021-07-31 17:16

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('wagtailseo', '0001_initial'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='seosettings',
            name='amp_pages',
        ),
    ]
